@@ -17,3 +17,5 @@ from common.rpc import search
 from common.rpc import secrets
 from common.rpc import sections
 from common.rpc import slack
+from common.rpc import ag_master
+from common.rpc import ag_worker
